@@ -96,7 +96,7 @@ void Plugin_AcquireImages::slotActivate()
         return;
     }
         
-    TQString from(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
+    TQString from(sender()->name());
     
     if (from == "scan_images")
     {
