@@ -55,28 +55,28 @@ extern "C"
 
 #include <kstandarddirs.h>
 #include <kcolorbutton.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kprogress.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <kinstance.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <kdialogbase.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kimageio.h>
 #include <kprocess.h>
 #include <klineeditdlg.h>
-#include <kio/jobclasses.h>
-#include <kio/netaccess.h>
-#include <kio/global.h>
-#include <kio/previewjob.h>
+#include <tdeio/jobclasses.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/global.h>
+#include <tdeio/previewjob.h>
 #include <kbuttonbox.h>
-#include <kdiroperator.h>
-#include <kdeversion.h>
+#include <tdediroperator.h>
+#include <tdeversion.h>
 #include <kurlrequester.h>
 #include <klineedit.h>
 
@@ -104,7 +104,7 @@ BatchProcessImagesDialog::BatchProcessImagesDialog( KURL::List urlList, KIPI::In
 {
     // Init. Tmp folder
 
-    KStandardDirs dir;
+    TDEStandardDirs dir;
     m_tmpFolder = dir.saveLocation("tmp", "kipi-batchprocessimagesplugin-" +
                                    TQString::number(getpid()) );
 
@@ -327,7 +327,7 @@ void BatchProcessImagesDialog::slotImageSelected( TQListViewItem * item )
 
     KURL url(IdemIndexed);
 
-    KIO::PreviewJob* m_thumbJob = KIO::filePreview( url, m_imageLabel->height() );
+    TDEIO::PreviewJob* m_thumbJob = TDEIO::filePreview( url, m_imageLabel->height() );
 
     connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             this, TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
@@ -475,10 +475,10 @@ bool BatchProcessImagesDialog::startProcess(void)
 
     KURL desturl(targetAlbum + "/" + item->nameDest());
 
-#if KDE_VERSION >= 0x30200
-    if ( KIO::NetAccess::exists( desturl, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
+#if TDE_VERSION >= 0x30200
+    if ( TDEIO::NetAccess::exists( desturl, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
 #else
-    if ( KIO::NetAccess::exists( desturl ) == true )
+    if ( TDEIO::NetAccess::exists( desturl ) == true )
 #endif
     {
        switch (overwriteMode())
@@ -590,21 +590,21 @@ bool BatchProcessImagesDialog::startProcess(void)
     }
 
     m_commandLine = TQString();
-    m_ProcessusProc = new KProcess;
+    m_ProcessusProc = new TDEProcess;
     m_commandLine.append(makeProcess(m_ProcessusProc, item, targetAlbum));
 
     item->changeOutputMess(m_commandLine + "\n\n");
 
-    connect(m_ProcessusProc, TQT_SIGNAL(processExited(KProcess *)),
-            this, TQT_SLOT(slotProcessDone(KProcess*)));
+    connect(m_ProcessusProc, TQT_SIGNAL(processExited(TDEProcess *)),
+            this, TQT_SLOT(slotProcessDone(TDEProcess*)));
 
-    connect(m_ProcessusProc, TQT_SIGNAL(receivedStdout(KProcess *, char*, int)),
-            this, TQT_SLOT(slotReadStd(KProcess*, char*, int)));
+    connect(m_ProcessusProc, TQT_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
+            this, TQT_SLOT(slotReadStd(TDEProcess*, char*, int)));
 
-    connect(m_ProcessusProc, TQT_SIGNAL(receivedStderr(KProcess *, char*, int)),
-            this, TQT_SLOT(slotReadStd(KProcess*, char*, int)));
+    connect(m_ProcessusProc, TQT_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
+            this, TQT_SLOT(slotReadStd(TDEProcess*, char*, int)));
 
-    bool result = m_ProcessusProc->start(KProcess::NotifyOnExit, KProcess::All);
+    bool result = m_ProcessusProc->start(TDEProcess::NotifyOnExit, TDEProcess::All);
     if(!result)
     {
        KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
@@ -615,13 +615,13 @@ bool BatchProcessImagesDialog::startProcess(void)
     return true;
 }
 
-void BatchProcessImagesDialog::slotReadStd(KProcess* /*proc*/, char *buffer, int buflen)
+void BatchProcessImagesDialog::slotReadStd(TDEProcess* /*proc*/, char *buffer, int buflen)
 {
     BatchProcessImagesItem *item = static_cast<BatchProcessImagesItem*>( m_listFile2Process_iterator->current() );
     item->changeOutputMess( TQString::fromLocal8Bit(buffer, buflen) );
 }
 
-void BatchProcessImagesDialog::slotProcessDone(KProcess* proc)
+void BatchProcessImagesDialog::slotProcessDone(TDEProcess* proc)
 {
     if ( m_convertStatus == PROCESS_DONE )
     {
@@ -714,10 +714,10 @@ void BatchProcessImagesDialog::slotProcessDone(KProcess* proc)
             {
                 KURL deleteImage(item->pathSrc());
     
-#if KDE_VERSION >= 0x30200
-                if ( KIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) ) == false )
+#if TDE_VERSION >= 0x30200
+                if ( TDEIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) ) == false )
 #else
-                if ( KIO::NetAccess::del( deleteImage ) == false )
+                if ( TDEIO::NetAccess::del( deleteImage ) == false )
 #endif
                 {
                     item->changeResult(i18n("Warning:"));
@@ -802,23 +802,23 @@ void BatchProcessImagesDialog::slotPreview(void)
             this, TQT_SLOT(slotPreviewStop()));
 
     m_previewOutput = "";
-    m_PreviewProc = new KProcess;
+    m_PreviewProc = new TDEProcess;
 
     m_previewOutput.append(makeProcess(m_PreviewProc, item, TQString(), true));
 
     *m_PreviewProc << m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG";
     m_previewOutput.append( " "  + m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG\n\n");
 
-    connect(m_PreviewProc, TQT_SIGNAL(processExited(KProcess *)),
-            this, TQT_SLOT(slotPreviewProcessDone(KProcess*)));
+    connect(m_PreviewProc, TQT_SIGNAL(processExited(TDEProcess *)),
+            this, TQT_SLOT(slotPreviewProcessDone(TDEProcess*)));
 
-    connect(m_PreviewProc, TQT_SIGNAL(receivedStdout(KProcess *, char*, int)),
-            this, TQT_SLOT(slotPreviewReadStd(KProcess*, char*, int)));
+    connect(m_PreviewProc, TQT_SIGNAL(receivedStdout(TDEProcess *, char*, int)),
+            this, TQT_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
 
-    connect(m_PreviewProc, TQT_SIGNAL(receivedStderr(KProcess *, char*, int)),
-            this, TQT_SLOT(slotPreviewReadStd(KProcess*, char*, int)));
+    connect(m_PreviewProc, TQT_SIGNAL(receivedStderr(TDEProcess *, char*, int)),
+            this, TQT_SLOT(slotPreviewReadStd(TDEProcess*, char*, int)));
 
-    bool result = m_PreviewProc->start(KProcess::NotifyOnExit, KProcess::All);
+    bool result = m_PreviewProc->start(TDEProcess::NotifyOnExit, TDEProcess::All);
     if(!result)
     {
         KMessageBox::error(this, i18n("Cannot start 'convert' program from 'ImageMagick' package;\n"
@@ -828,12 +828,12 @@ void BatchProcessImagesDialog::slotPreview(void)
     }
 }
 
-void BatchProcessImagesDialog::slotPreviewReadStd(KProcess* /*proc*/, char *buffer, int buflen)
+void BatchProcessImagesDialog::slotPreviewReadStd(TDEProcess* /*proc*/, char *buffer, int buflen)
 {
     m_previewOutput.append( TQString::fromLocal8Bit(buffer, buflen) );
 }
 
-void BatchProcessImagesDialog::slotPreviewProcessDone(KProcess* proc)
+void BatchProcessImagesDialog::slotPreviewProcessDone(TDEProcess* proc)
 {
     if (!m_PreviewProc->normalExit())
     {
@@ -867,10 +867,10 @@ void BatchProcessImagesDialog::slotPreviewProcessDone(KProcess* proc)
 
        KURL deletePreviewImage(m_tmpFolder + "/" + TQString::number(getpid()) + "preview.PNG");
 
-#if KDE_VERSION >= 0x30200
-       KIO::NetAccess::del( deletePreviewImage, TQT_TQWIDGET(kapp->activeWindow()) );
+#if TDE_VERSION >= 0x30200
+       TDEIO::NetAccess::del( deletePreviewImage, TQT_TQWIDGET(kapp->activeWindow()) );
 #else
-       KIO::NetAccess::del( deletePreviewImage );
+       TDEIO::NetAccess::del( deletePreviewImage );
 #endif
     }
     else
@@ -1028,12 +1028,12 @@ void BatchProcessImagesDialog::processAborted(bool removeFlag)
        KURL deleteImage = m_destinationURL->url();
        deleteImage.addPath(item->nameDest());
 
-#if KDE_VERSION >= 0x30200
-       if ( KIO::NetAccess::exists( deleteImage, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
-          KIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) );
+#if TDE_VERSION >= 0x30200
+       if ( TDEIO::NetAccess::exists( deleteImage, false, TQT_TQWIDGET(kapp->activeWindow()) ) == true )
+          TDEIO::NetAccess::del( deleteImage, TQT_TQWIDGET(kapp->activeWindow()) );
 #else
-       if ( KIO::NetAccess::exists( deleteImage ) == true )
-          KIO::NetAccess::del( deleteImage );
+       if ( TDEIO::NetAccess::exists( deleteImage ) == true )
+          TDEIO::NetAccess::del( deleteImage );
 #endif
     }
 
@@ -1066,10 +1066,10 @@ TQString BatchProcessImagesDialog::RenameTargetImageFile(TQFileInfo *fi)
                     + "." + fi->filePath().section('.', -1 );
     }
     while ( Enumerator < 100 &&
-#if KDE_VERSION >= 0x30200
-            KIO::NetAccess::exists( NewDestUrl, true, TQT_TQWIDGET(kapp->activeWindow()) )
+#if TDE_VERSION >= 0x30200
+            TDEIO::NetAccess::exists( NewDestUrl, true, TQT_TQWIDGET(kapp->activeWindow()) )
 #else
-            KIO::NetAccess::exists( NewDestUrl )
+            TDEIO::NetAccess::exists( NewDestUrl )
 #endif
             == true );
 
@@ -1078,7 +1078,7 @@ TQString BatchProcessImagesDialog::RenameTargetImageFile(TQFileInfo *fi)
     return (NewDestUrl.path());
 }
 
-TQString BatchProcessImagesDialog::extractArguments(KProcess *proc)
+TQString BatchProcessImagesDialog::extractArguments(TDEProcess *proc)
 {
     TQString retArguments;
     TQValueList<TQCString> argumentsList = proc->args();
