@@ -33,9 +33,9 @@
 
 // KDE includes.
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdeversion.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
 #include <kcalendarsystem.h>
 #include <kdebug.h>
 
@@ -88,19 +88,19 @@ void CalPainter::paint(bool useDeviceMetrics)
     // --------------------------------------------------
 
     int days[42];
-    int startDayOffset = KGlobal::locale()->weekStartDay();
+    int startDayOffset = TDEGlobal::locale()->weekStartDay();
 
     for (int i=0; i<42; i++)
         days[i] = -1;
 
     TQDate d;
-    KGlobal::locale()->calendar()->setYMD(d, year_, month_, 1);
+    TDEGlobal::locale()->calendar()->setYMD(d, year_, month_, 1);
     int s = d.dayOfWeek();
 
     if (s+7-startDayOffset >= 7)
             s=s-7;
 
-    for (int i=s; i<(s+KGlobal::locale()->calendar()->daysInMonth(d)); i++) {
+    for (int i=s; i<(s+TDEGlobal::locale()->calendar()->daysInMonth(d)); i++) {
         days[i + (7-startDayOffset)] = i-s+1;
     }
 
@@ -217,10 +217,10 @@ void CalPainter::paint(bool useDeviceMetrics)
                       TQString::number(year_));
 #if KDE_IS_VERSION(3,2,0)
     painter->drawText(rCalHeader, TQt::AlignRight|TQt::AlignVCenter,
-                      KGlobal::locale()->calendar()->monthName(month_, year_));
+                      TDEGlobal::locale()->calendar()->monthName(month_, year_));
 #else
     painter->drawText(rCalHeader, TQt::AlignRight|TQt::AlignVCenter,
-                      KGlobal::locale()->monthName(month_));
+                      TDEGlobal::locale()->monthName(month_));
 #endif
     painter->restore();
 
@@ -251,10 +251,10 @@ void CalPainter::paint(bool useDeviceMetrics)
         rsmall.setHeight(r.height() - 2);
 #if KDE_IS_VERSION(3,2,0)
         painter->drawText(rsmall, TQt::AlignRight|TQt::AlignBottom,
-                          KGlobal::locale()->calendar()->weekDayName(dayname, true));
+                          TDEGlobal::locale()->calendar()->weekDayName(dayname, true));
 #else
         painter->drawText(rsmall, TQt::AlignRight|TQt::AlignBottom,
-                          KGlobal::locale()->weekDayName(dayname, true));
+                          TDEGlobal::locale()->weekDayName(dayname, true));
 #endif
 
     }
@@ -315,19 +315,19 @@ CalBlockPainter::CalBlockPainter(TQObject *parent, int year, int month,
     // --------------------------------------------------
 
     int  days[42];
-    int startDayOffset = KGlobal::locale()->weekStartDay();
+    int startDayOffset = TDEGlobal::locale()->weekStartDay();
 
     for (int i=0; i<42; i++)
         days[i] = -1;
 
     TQDate d;
-    KGlobal::locale()->calendar()->setYMD(d, year, month, 1);
+    TDEGlobal::locale()->calendar()->setYMD(d, year, month, 1);
     int s = d.dayOfWeek();
 
     if (s+7-startDayOffset >= 7)
             s=s-7;
 
-    for (int i=s; i<(s+KGlobal::locale()->calendar()->daysInMonth(d)); i++) {
+    for (int i=s; i<(s+TDEGlobal::locale()->calendar()->daysInMonth(d)); i++) {
         days[i+(7-startDayOffset)] = i-s+1;
     }
 
@@ -443,10 +443,10 @@ CalBlockPainter::CalBlockPainter(TQObject *parent, int year, int month,
                       TQString::number(year));
 #if KDE_IS_VERSION(3,2,0)
     painter->drawText(rCalHeader, TQt::AlignRight|TQt::AlignVCenter,
-                      KGlobal::locale()->calendar()->monthName(month, year));
+                      TDEGlobal::locale()->calendar()->monthName(month, year));
 #else
     painter->drawText(rCalHeader, TQt::AlignRight|TQt::AlignVCenter,
-                      KGlobal::locale()->monthName(month));
+                      TDEGlobal::locale()->monthName(month));
 #endif
     painter->restore();
 
@@ -477,10 +477,10 @@ CalBlockPainter::CalBlockPainter(TQObject *parent, int year, int month,
         rsmall.setHeight(r.height() - 2);
 #if KDE_IS_VERSION(3,2,0)
         painter->drawText(rsmall, TQt::AlignRight|TQt::AlignBottom,
-                          KGlobal::locale()->calendar()->weekDayName(dayname, true));
+                          TDEGlobal::locale()->calendar()->weekDayName(dayname, true));
 #else
         painter->drawText(rsmall, TQt::AlignRight|TQt::AlignBottom,
-                          KGlobal::locale()->weekDayName(dayname, true));
+                          TDEGlobal::locale()->weekDayName(dayname, true));
 #endif
     }
 
@@ -553,7 +553,7 @@ CalBlockPainter::CalBlockPainter(TQObject *parent, int year, int month,
         }
 
         image_ = new TQImage(img.smoothScale(rImage.width(), rImage.height(),
-                                            TQ_ScaleMin));
+                                            TQImage::ScaleMin));
         // Center the image
         int x = rImage.x() + rImage.width()/2 - image_->width()/2;
         int y = rImage.y() + rImage.height()/2 - image_->height()/2;
