@@ -401,7 +401,7 @@ bool FlickrTalker::addPhoto(const TQString& photoPath, const FPhotoInfo& info,
         path = locateLocal("tmp", TQFileInfo(photoPath).baseName().stripWhiteSpace() + ".jpg");
 
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
-            image = image.smoothScale(maxDim, maxDim, TQ_ScaleMin);
+            image = image.smoothScale(maxDim, maxDim, TQImage::ScaleMin);
 
         image.save(path, "JPEG", imageQuality);
 
