@@ -73,7 +73,7 @@ FlickrWidget::FlickrWidget(TQWidget* parent, KIPI::Interface *iface)
     KSeparator *line          = new KSeparator(Horizontal, this);
     m_tab                     = new KTabWidget(this);
     KActiveLabel *headerLabel = new KActiveLabel(this);
-    headerLabel->setFocusPolicy(TQ_NoFocus);
+    headerLabel->setFocusPolicy(TQWidget::NoFocus);
     headerLabel->setLinkUnderline(false);
     headerLabel->setText(i18n("<qt><b><h2><a href='http://www.flickr.com'>"
                               "<font color=\"#0065DE\">flick</font>"
