@@ -222,7 +222,7 @@ bool GalleryTalker::addPhoto( const TQString& albumName,
         // image file - see if we need to rescale it
         if (rescale && (image.width() > maxDim || image.height() > maxDim))
         {
-            image = image.smoothScale(maxDim, maxDim, TQ_ScaleMin);
+            image = image.smoothScale(maxDim, maxDim, TQImage::ScaleMin);
             path = locateLocal("tmp", KURL(photoPath).filename());
             image.save(path, TQImageIO::imageFormat(photoPath));
 
