@@ -92,8 +92,8 @@ bool Utils::updateMetadataImageMagick(const TQString& src, TQString& err)
     }
 
     TQImage img(src);
-    TQImage iptcPreview   = img.scale(1280, 1024, TQ_ScaleMin);
-    TQImage exifThumbnail = iptcPreview.scale(160, 120, TQ_ScaleMin);
+    TQImage iptcPreview   = img.scale(1280, 1024, TQImage::ScaleMin);
+    TQImage exifThumbnail = iptcPreview.scale(160, 120, TQImage::ScaleMin);
 
     KExiv2Iface::KExiv2 meta;
     meta.load(src);
