@@ -387,7 +387,7 @@ void GPController::error(const TQString& errorMsg) {
 }
 
 void GPController::scaleHighlightThumbnail(TQImage& thumbnail) {
-    thumbnail = thumbnail.smoothScale(100, 100, TQ_ScaleMin);
+    thumbnail = thumbnail.smoothScale(100, 100, TQImage::ScaleMin);
     TQColor darkColor(48, 48, 48);
     TQColor lightColor(215, 215, 215);
     int w = thumbnail.width();
