@@ -30,11 +30,11 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialog.h>
 #include <klineedit.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <kactivelabel.h>
 
 // LibKExiv2 includes. 
