@@ -66,24 +66,24 @@ extern "C"
 
 #include <kprogress.h>
 #include <kprocess.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdefiledialog.h>
 #include <kcolordialog.h>
 #include <klineedit.h>
 #include <kcolorbutton.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include <kbuttonbox.h>
 #include <kurl.h>
 #include <kimageio.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 #include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 // KIPI include files
 
@@ -130,7 +130,7 @@ private:
 /////////////////////////////////////////////////////////////////////////////////////////////
 
 ListImageItems::ListImageItems(TQWidget *parent, const char *name)
-              : KListBox(parent, name)
+              : TDEListBox(parent, name)
 {
     setSelectionMode (TQListBox::Extended);
     setAcceptDrops(true);
@@ -188,13 +188,13 @@ KImg2mpgData::KImg2mpgData(KIPI::Interface* interface, TQWidget *parent, const c
   m_Encoding = false;
   m_Abort = false;
 
-  m_Icons = new KIconLoader( TQString( "kipi" ) );
+  m_Icons = new TDEIconLoader( TQString( "kipi" ) );
   m_NoneLabel = i18n ("none");
 
   // Set buttons icon
 
-  m_MPEGOutputBUTTONFilename->setIconSet( SmallIconSet( "fileopen" ) );
-  m_AudioInputBUTTONFilename->setIconSet( SmallIconSet( "fileopen" ) );
+  m_MPEGOutputBUTTONFilename->setIconSet( SmallIconSet( "document-open" ) );
+  m_AudioInputBUTTONFilename->setIconSet( SmallIconSet( "document-open" ) );
 
   // Signal/Slot connections
 
@@ -245,7 +245,7 @@ KImg2mpgData::KImg2mpgData(KIPI::Interface* interface, TQWidget *parent, const c
 
   m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("MPEG Slideshow"),
                                       0,
-                                      KAboutData::License_GPL,
+                                      TDEAboutData::License_GPL,
                                       I18N_NOOP("A Kipi plugin for encoding images to an MPEG file."),
                                                 "(c) 2003-2004, Gilles Caulier");
 
@@ -306,7 +306,7 @@ void KImg2mpgData::slotMPEGFilenameDialog( void )
 {
   TQString temp;
 
-  temp = KFileDialog::getOpenFileName(KGlobalSettings::documentPath(),
+  temp = KFileDialog::getOpenFileName(TDEGlobalSettings::documentPath(),
                                       TQString( "*.mpg" ),
                                       this,
                                       i18n("Select MPEG Output File") );
@@ -323,7 +323,7 @@ void KImg2mpgData::slotAudioFilenameDialog( void )
 {
   TQString temp;
 
-  temp = KFileDialog::getOpenFileName(KGlobalSettings::documentPath(),
+  temp = KFileDialog::getOpenFileName(TDEGlobalSettings::documentPath(),
                                       TQString( "*.wav *.mp2 *.mp3 *.ogg" ),
                                       this,
                                       i18n("Select Audio Input File") );
@@ -425,7 +425,7 @@ void KImg2mpgData::slotImagesFilesSelected( TQListBoxItem *item )
 
   if ( m_thumbJob ) delete m_thumbJob;
 
-  m_thumbJob = KIO::filePreview( url, m_ImageLabel->width() );
+  m_thumbJob = TDEIO::filePreview( url, m_ImageLabel->width() );
 
   connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
            TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
@@ -504,7 +504,7 @@ void KImg2mpgData::slotClose()
 
 void KImg2mpgData::slotEncode( void )
 {
-  m_Proc = new KProcess;
+  m_Proc = new TDEProcess;
   TQColor BackGroundColor;
   TQString HexColor;
   TQString Temp;
@@ -540,7 +540,7 @@ void KImg2mpgData::slotEncode( void )
    }
 
   // Init. Tmp folder
-  KStandardDirs dir;
+  TDEStandardDirs dir;
   m_TmpFolderConfig = dir.saveLocation("tmp", "kipi-mpegencoderplugin-" +
                                        TQString::number(getpid()) );
 
@@ -697,14 +697,14 @@ void KImg2mpgData::slotEncode( void )
     m_CommandLine = m_CommandLine + " \"" + FileName + "\" ";
   }
 
-  connect(m_Proc, TQT_SIGNAL(processExited(KProcess *)),this,
-          TQT_SLOT(EncodeDone(KProcess*)));
+  connect(m_Proc, TQT_SIGNAL(processExited(TDEProcess *)),this,
+          TQT_SLOT(EncodeDone(TDEProcess*)));
 
-  connect(m_Proc, TQT_SIGNAL(receivedStderr(KProcess *,char*,int)),this,
-          TQT_SLOT(readStderr(KProcess*,char*,int)));
+  connect(m_Proc, TQT_SIGNAL(receivedStderr(TDEProcess *,char*,int)),this,
+          TQT_SLOT(readStderr(TDEProcess*,char*,int)));
 
   m_Img2mpgPidNum = -1;
-  bool result = m_Proc->start(KProcess::NotifyOnExit , KProcess::All);
+  bool result = m_Proc->start(TDEProcess::NotifyOnExit , TDEProcess::All);
   
   if(!result)
     {
@@ -769,7 +769,7 @@ void KImg2mpgData::slotOptionDlgOkClicked( void )
 
 void KImg2mpgData::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("mpegencoder",
+    TDEApplication::kApplication()->invokeHelp("mpegencoder",
                                              "kipi-plugins");
 }
 
@@ -809,7 +809,7 @@ void KImg2mpgData::ShowNumberImages( int Number )
 
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
+void KImg2mpgData::readStderr(TDEProcess *, char *buffer, int buflen)
 {
   TQString NewString2;
   int ImgNum;
@@ -898,7 +898,7 @@ void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
 
 /////////////////////////////////////////////////////////////////////////////////////////////
 
-void KImg2mpgData::EncodeDone(KProcess*)
+void KImg2mpgData::EncodeDone(TDEProcess*)
 {
   reset();
 
@@ -951,7 +951,7 @@ void KImg2mpgData::EncodeDone(KProcess*)
 
 TQPixmap KImg2mpgData::LoadIcon( TQString Name, int Group )
 {
-  return m_Icons->loadIcon( Name, (KIcon::Group)Group );
+  return m_Icons->loadIcon( Name, (TDEIcon::Group)Group );
 }
 
 
@@ -1031,7 +1031,7 @@ void KImg2mpgData::reset()
 
 void KImg2mpgData::writeSettings()
 {
-  m_config = new KConfig("kipirc");
+  m_config = new TDEConfig("kipirc");
   m_config->setGroup("MPEGEncoder Settings");
 
   m_VideoFormatConfig = m_VideoFormatComboBox->currentText();
@@ -1070,7 +1070,7 @@ void KImg2mpgData::writeSettings()
 
 void KImg2mpgData::readSettings()
 {
-  m_config = new KConfig("kipirc");
+  m_config = new TDEConfig("kipirc");
   m_config->setGroup("MPEGEncoder Settings");
 
   m_VideoFormatConfig = m_config->readEntry("VideoFormat", "XVCD");
@@ -1107,7 +1107,7 @@ void KImg2mpgData::readSettings()
   m_AudioInputFileConfig = m_config->readPathEntry("AudioInputFile");
   m_AudioInputEDITFilename->setText(m_AudioInputFileConfig);
 
-  m_MPEGOutputFileConfig = m_config->readPathEntry("MPEGOutputFile", KGlobalSettings::documentPath() + "output.mpg");
+  m_MPEGOutputFileConfig = m_config->readPathEntry("MPEGOutputFile", TDEGlobalSettings::documentPath() + "output.mpg");
   m_MPEGOutputEDITFilename->setText(m_MPEGOutputFileConfig);
 
   m_IMBinFolderConfig = m_config->readPathEntry("ImageMagickBinFolder", "/usr/bin");
