@@ -78,7 +78,7 @@ void CropFrame::init(TPhoto *photo, int width, int height, bool autoRotate, bool
   matrix.rotate(m_photo->rotation);
   scaledImg = scaledImg.xForm(matrix);
 
-  scaledImg = scaledImg.smoothScale(this->width(), this->height(), TQ_ScaleMin);
+  scaledImg = scaledImg.smoothScale(this->width(), this->height(), TQImage::ScaleMin);
 
   m_pixmap = new TQPixmap();
   m_pixmap->convertFromImage(scaledImg);
