@@ -827,7 +827,7 @@ bool FrmPrintWizard::paintOnePage(TQImage &p, TQPtrList<TPhoto> photos, TQPtrLis
     int h  = NINT((double)layout->height() * yRatio);
 
     // We can use scaleFree because the crop frame should have the proper dimensions.
-    img = img.smoothScale(w, h, TQ_ScaleFree);
+    img = img.smoothScale(w, h, TQImage::ScaleFree);
     // don't have drawimage, so we copy the pixels over manually
     for(int srcY = 0; srcY < img.height(); srcY++)
       for(int srcX = 0; srcX < img.width(); srcX++)
