@@ -632,7 +632,7 @@ void BatchDialog::customEvent(TQCustomEvent *event)
                     {
                         if (!d->image.isNull())
                         {
-                            TQPixmap pix = TQPixmap(d->image.scale(64, 64, TQ_ScaleMin));
+                            TQPixmap pix = TQPixmap(d->image.scale(64, 64, TQImage::ScaleMin));
                             rawItem->viewItem->setThumbnail(pix);
                         }
                         rawItem->viewItem->setText(3, d->message);
