@@ -95,7 +95,7 @@ void PreviewWidget::load(const TQString& file)
 
     if (!d->image.isNull()) 
     {
-        TQImage img = d->image.scale(width(),height(),TQ_ScaleMin);
+        TQImage img = d->image.scale(width(),height(),TQImage::ScaleMin);
         int x = d->pix->width()/2 - img.width()/2;
         int y = d->pix->height()/2 - img.height()/2;
 
@@ -179,7 +179,7 @@ void PreviewWidget::slotResize()
     {
         if (!d->image.isNull()) 
         {
-            TQImage img = d->image.scale(width(),height(), TQ_ScaleMin);
+            TQImage img = d->image.scale(width(),height(), TQImage::ScaleMin);
             int x = d->pix->width()/2 - img.width()/2;
             int y = d->pix->height()/2 - img.height()/2;
 
