@@ -565,7 +565,7 @@ void SingleDialog::customEvent(TQCustomEvent *event)
             {
                 case(IDENTIFY_FULL): 
                 {
-                    TQPixmap pix = TQPixmap(d->image.scale(256, 256, TQ_ScaleMin));
+                    TQPixmap pix = TQPixmap(d->image.scale(256, 256, TQImage::ScaleMin));
                     identified(d->filePath, d->message, pix);
                     busy(false);
                     break;
