@@ -506,7 +506,7 @@ void SlideShowGL::loadImage()
         black.fill(TQt::black.rgb());
 	    
 /*        image = image.smoothScale(width(), height(),
-                                  TQ_ScaleMin);*/
+                                  TQImage::ScaleMin);*/
         montage(image, black);
 
         black = black.smoothScale(m_width, m_height);
